## $Id: viewlets.py 15330 2019-02-14 15:55:27Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.component import getUtility
from waeup.kofa.interfaces import REGISTERED
from waeup.kofa.students.interfaces import (
    IStudent, IStudentsUtils, IStudentStudyLevel)
from waeup.kofa.students.workflow import PAID
from waeup.kofa.students.viewlets import (
    AddPreviousPaymentActionButton, AddBalancePaymentActionButton,
    ManageActionButton, StudentBaseDisplayFormPage,
    StudentPassportActionButton,
    StudyCourseTranscriptActionButton,
    TranscriptSlipActionButton,
    DownloadCSVFileActionButton,
    DownloadTicketOverviewActionButton)
from waeup.kofa.students.browser import StudyLevelDisplayFormPage

from waeup.aaue.students.interfaces import (
    ICustomStudent, ICustomStudentStudyLevel)
from waeup.aaue.students.browser import CustomStudentPersonalDisplayFormPage
from waeup.aaue.interfaces import MessageFactory as _

#class AddPreviousPaymentActionButton(AddPreviousPaymentActionButton):

#    @property
#    def target_url(self):
#        return ''

#class AddBalancePaymentActionButton(AddBalancePaymentActionButton):

#    @property
#    def target_url(self):
#        return ''

class GetMatricNumberActionButton(ManageActionButton):
    grok.order(10)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    #grok.require('waeup.manageStudent')
    icon = 'actionicon_count.png'
    text = _('Get Matriculation Number')

    @property
    def target_url(self):
        students_utils = getUtility(IStudentsUtils)
        if self.context.matric_number:
            return ''
        error, matric_number = students_utils.constructMatricNumber(
            self.context)
        if error:
            return ''
        return self.view.url(self.view.context, 'get_matric_number')

class MatricNumberSlipActionButton(ManageActionButton):
    grok.order(10)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download matriculation number slip')
    target = 'matric_number_slip.pdf'

    @property
    def target_url(self):
        if self.context.state not in (PAID,) or not self.context.is_fresh \
            or not self.context.matric_number:
            return ''
        return self.view.url(self.view.context, self.target)

class CourseRegistrationSlipActionButton(ManageActionButton):
    grok.order(5)
    grok.context(ICustomStudentStudyLevel)
    grok.view(StudyLevelDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download course registration slip')
    target = 'course_registration_slip.pdf'

    @property
    def target_url(self):
        is_current = self.context.__parent__.is_current
        if not is_current:
            return ''
        if self.context.student.state != REGISTERED \
            and self.context.student.current_level == self.context.level:
            return ''
        return self.view.url(self.view.context, self.target)

class ExaminationScheduleSlipActionButton(ManageActionButton):
    grok.order(10)
    grok.context(ICustomStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download examination schedule slip')
    target = 'examination_schedule_slip.pdf'

    @property
    def target_url(self):
        if self.context.flash_notice \
            and 'exam' in self.context.flash_notice.lower():
            return self.view.url(self.view.context, self.target)
        return False

class PersonalDataSlipActionButton(ManageActionButton):
    grok.order(3)
    grok.context(ICustomStudent)
    grok.view(CustomStudentPersonalDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download personal data slip')
    target = 'personal_data_slip.pdf'

    @property
    def target_url(self):
        if not self.context.father_name:
            return ''
        return self.view.url(self.view.context, self.target)

class StudentPassportActionButton(StudentPassportActionButton):
    """Inherit from same class in base package, not from kofacustom.nigeria 
    which requires that no application slip exists.
    """

class CustomStudyCourseTranscriptActionButton(StudyCourseTranscriptActionButton):
    #grok.require('waeup.viewStudent')
    grok.name('transcript')

class CustomTranscriptSlipActionButton(TranscriptSlipActionButton):
    #grok.require('waeup.viewStudent')
    grok.name('transcript_slip')

class CustomDownloadCSVFileActionButton(DownloadCSVFileActionButton):
    """ 'Download csv file' button for courses.
    """

    @property
    def target_url(self):
        if self.view.__name__ == 'edit_prev_scores':
            return self.view.url(self.view.context, 'download_prev_scores')
        return self.view.url(self.view.context, 'download_scores')

class CustomDownloadTicketOverviewActionButton(
    DownloadTicketOverviewActionButton):
    """ 'Download ticket overview' button for courses.
    """

    @property
    def target_url(self):
        if self.view.__name__ == 'edit_prev_scores':
            return ''
        return self.view.url(self.view.context, 'coursetickets.pdf')

class StudyLevelRepairActionButton(ManageActionButton):
    grok.order(2)
    grok.context(IStudentStudyLevel)
    grok.view(StudyLevelDisplayFormPage)
    grok.require('waeup.editStudyLevel')
    text = _('Repair course list')
    target = 'repair'
    icon = 'actionicon_repair1.png'

    @property
    def target_url(self):
        try:
            studylevel_repair_enabled = grok.getSite()['configuration'][
                str(self.context.level_session)].studylevel_repair_enabled
        except KeyError:
            return ''
        if not studylevel_repair_enabled:
            return ''
        return self.view.url(self.view.context, self.target)
